#' Calculation of the Confusion Matrix
#'
#' Calculates the the Confusion Matrix
#'
#' @param true.values correct labels of data (1-2)
#' @param predicted.values predicted values of labes, returned by classifier
#' @param positive An optional character string for the factor level that corresponds to a "positive" result
#'
#' @return the confution matrix
#'
#' @examples
#' true.values <- sample(0:1, 1000, replace=TRUE, prob=c(0.5, 0.5))
#' predicted.values <- sample(0:1, 1000, replace=TRUE, prob=c(0.5, 0.5))
#' confusion.matrix( true.values, predicted.values )
#'
#' @author Aleksander Denisiuk, \email{denisiuk@@matman.uwm.edu.pl}
#' @references \url{https://en.wikipedia.org/wiki/Confusion_matrix}
#' @seealso \code{\link[MLmetrics]{ConfusionMatrix}}
#' @keywords confusion matrix
#'
#' @export

confusion.matrix <- function( true.values, predicted.values, positive=1 ){
   true.positive <- sum ( true.values==positive & predicted.values==positive)
   true.negative <- sum ( true.values!=positive & predicted.values!=positive)
   false.positive <- sum ( true.values!=positive & predicted.values==positive)
   false.negative <- sum ( true.values==positive & predicted.values!=positive)
   matrix( c(true.positive, false.negative, false.positive, true.negative), ncol=2, 
    dimnames = list(c("actual.positive", "actual.negative"),
                     c("predicted.positive", "predicted.negative")),
    byrow = TRUE
         )

}

